from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from .._jsii import *

from ..cdk_graph import (
    CdkGraphArtifact as _CdkGraphArtifact_0059de6d,
    ICdkGraphPlugin as _ICdkGraphPlugin_b5ef2d02,
    IGraphPluginBindCallback as _IGraphPluginBindCallback_58b6edd3,
    IGraphReportCallback as _IGraphReportCallback_858cc871,
)


@jsii.implements(_ICdkGraphPlugin_b5ef2d02)
class CdkGraphThreatComposerPlugin(
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws/pdk.cdk_graph_plugin_threat_composer.CdkGraphThreatComposerPlugin",
):
    '''CdkGraphThreatComposerPlugin is a {@link ICdkGraphPluginCdkGraph Plugin} implementation for generating Threat Composer threat models.

    :see: https://github.com/awslabs/threat-composer
    '''

    def __init__(
        self,
        *,
        application_details: typing.Optional[typing.Union["ThreatComposerApplicationDetails", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param application_details: Details about the application to include in the threat model.
        '''
        options = CdkGraphThreatComposerPluginOptions(
            application_details=application_details
        )

        jsii.create(self.__class__, self, [options])

    @jsii.python.classproperty
    @jsii.member(jsii_name="ID")
    def ID(cls) -> builtins.str:
        '''Fixed ID of the threat-composer plugin.'''
        return typing.cast(builtins.str, jsii.sget(cls, "ID"))

    @jsii.python.classproperty
    @jsii.member(jsii_name="VERSION")
    def VERSION(cls) -> builtins.str:
        '''Curent semantic version of the threat-composer plugin.'''
        return typing.cast(builtins.str, jsii.sget(cls, "VERSION"))

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        '''Unique identifier for this plugin.

        :inheritdoc: true
        '''
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> builtins.str:
        '''Plugin version.

        :inheritdoc: true
        '''
        return typing.cast(builtins.str, jsii.get(self, "version"))

    @builtins.property
    @jsii.member(jsii_name="dependencies")
    def dependencies(self) -> typing.Optional[typing.List[builtins.str]]:
        '''List of plugins this plugin depends on, including optional semver version (eg: ["foo", "bar@1.2"]).

        :inheritdoc: true
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "dependencies"))

    @builtins.property
    @jsii.member(jsii_name="threatModelArtifact")
    def threat_model_artifact(self) -> typing.Optional[_CdkGraphArtifact_0059de6d]:
        '''Retrieve the threat model artifact.'''
        return typing.cast(typing.Optional[_CdkGraphArtifact_0059de6d], jsii.get(self, "threatModelArtifact"))

    @builtins.property
    @jsii.member(jsii_name="bind")
    def bind(self) -> _IGraphPluginBindCallback_58b6edd3:
        '''Binds the plugin to the CdkGraph instance.

        Enables plugins to receive base configs.

        :inheritdoc: true
        '''
        return typing.cast(_IGraphPluginBindCallback_58b6edd3, jsii.get(self, "bind"))

    @bind.setter
    def bind(self, value: _IGraphPluginBindCallback_58b6edd3) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__004df50936b7e9d66b1ed9050f1929103969ae05c656b62aa74d1e4e090c0bb1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "bind", value) # pyright: ignore[reportArgumentType]

    @builtins.property
    @jsii.member(jsii_name="report")
    def report(self) -> typing.Optional[_IGraphReportCallback_858cc871]:
        '''Generate asynchronous reports based on the graph.

        This is not automatically called when synthesizing CDK.
        Developer must explicitly add ``await graphInstance.report()`` to the CDK bin or invoke this outside
        of the CDK synth. In either case, the plugin receives the in-memory graph interface when invoked, as the
        CdkGraph will deserialize the graph prior to invoking the plugin report.

        :inheritdoc: true
        '''
        return typing.cast(typing.Optional[_IGraphReportCallback_858cc871], jsii.get(self, "report"))

    @report.setter
    def report(self, value: typing.Optional[_IGraphReportCallback_858cc871]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__035069cd2d747ed069143fb7dcd15cc668561fda5e1131e69067e8390c369b5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "report", value) # pyright: ignore[reportArgumentType]


@jsii.data_type(
    jsii_type="@aws/pdk.cdk_graph_plugin_threat_composer.CdkGraphThreatComposerPluginOptions",
    jsii_struct_bases=[],
    name_mapping={"application_details": "applicationDetails"},
)
class CdkGraphThreatComposerPluginOptions:
    def __init__(
        self,
        *,
        application_details: typing.Optional[typing.Union["ThreatComposerApplicationDetails", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''Options for the Threat Composer CDK Graph plugin.

        :param application_details: Details about the application to include in the threat model.
        '''
        if isinstance(application_details, dict):
            application_details = ThreatComposerApplicationDetails(**application_details)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__639c16f872bbcd9a96470baacb14439baa1a77a4b72bca89f8f99db36b96223a)
            check_type(argname="argument application_details", value=application_details, expected_type=type_hints["application_details"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if application_details is not None:
            self._values["application_details"] = application_details

    @builtins.property
    def application_details(
        self,
    ) -> typing.Optional["ThreatComposerApplicationDetails"]:
        '''Details about the application to include in the threat model.'''
        result = self._values.get("application_details")
        return typing.cast(typing.Optional["ThreatComposerApplicationDetails"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CdkGraphThreatComposerPluginOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.cdk_graph_plugin_threat_composer.ThreatComposerApplicationDetails",
    jsii_struct_bases=[],
    name_mapping={"description": "description", "name": "name"},
)
class ThreatComposerApplicationDetails:
    def __init__(
        self,
        *,
        description: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Details about the application to include in the threat model.

        :param description: A description of the application.
        :param name: The name of the application. Default: "My Application"
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9303e5c0974005851dfe891098a48818ab06b87628678818de66c1e67bea662)
            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''A description of the application.'''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of the application.

        :default: "My Application"
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ThreatComposerApplicationDetails(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CdkGraphThreatComposerPlugin",
    "CdkGraphThreatComposerPluginOptions",
    "ThreatComposerApplicationDetails",
]

publication.publish()

def _typecheckingstub__004df50936b7e9d66b1ed9050f1929103969ae05c656b62aa74d1e4e090c0bb1(
    value: _IGraphPluginBindCallback_58b6edd3,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__035069cd2d747ed069143fb7dcd15cc668561fda5e1131e69067e8390c369b5a(
    value: typing.Optional[_IGraphReportCallback_858cc871],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__639c16f872bbcd9a96470baacb14439baa1a77a4b72bca89f8f99db36b96223a(
    *,
    application_details: typing.Optional[typing.Union[ThreatComposerApplicationDetails, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9303e5c0974005851dfe891098a48818ab06b87628678818de66c1e67bea662(
    *,
    description: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass



from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from .._jsii import *

import aws_cdk as _aws_cdk_ceddda9d
import aws_cdk.aws_cognito as _aws_cdk_aws_cognito_ceddda9d
import aws_cdk.aws_cognito_identitypool_alpha as _aws_cdk_aws_cognito_identitypool_alpha_e0ee7798
import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
import constructs as _constructs_77d1e7e8


class UserIdentity(
    _constructs_77d1e7e8.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws/pdk.identity.UserIdentity",
):
    '''Creates a UserPool and Identity Pool with sane defaults configured intended for usage from a web client.'''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        allow_signup: typing.Optional[builtins.bool] = None,
        identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
        user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param allow_signup: Allow self sign up. Default: - false
        :param identity_pool_options: Configuration for the Identity Pool.
        :param user_pool: User provided Cognito UserPool. Default: - a userpool with mfa will be created.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3dda65570bf25bbaff83417268c7c0a7e08163811a20c7a7401e4a59fb1b444b)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = UserIdentityProps(
            allow_signup=allow_signup,
            identity_pool_options=identity_pool_options,
            user_pool=user_pool,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @builtins.property
    @jsii.member(jsii_name="identityPool")
    def identity_pool(
        self,
    ) -> _aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPool:
        return typing.cast(_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPool, jsii.get(self, "identityPool"))

    @builtins.property
    @jsii.member(jsii_name="userPool")
    def user_pool(self) -> _aws_cdk_aws_cognito_ceddda9d.UserPool:
        return typing.cast(_aws_cdk_aws_cognito_ceddda9d.UserPool, jsii.get(self, "userPool"))

    @builtins.property
    @jsii.member(jsii_name="userPoolClient")
    def user_pool_client(self) -> _aws_cdk_aws_cognito_ceddda9d.UserPoolClient:
        return typing.cast(_aws_cdk_aws_cognito_ceddda9d.UserPoolClient, jsii.get(self, "userPoolClient"))


@jsii.data_type(
    jsii_type="@aws/pdk.identity.UserIdentityProps",
    jsii_struct_bases=[],
    name_mapping={
        "allow_signup": "allowSignup",
        "identity_pool_options": "identityPoolOptions",
        "user_pool": "userPool",
    },
)
class UserIdentityProps:
    def __init__(
        self,
        *,
        allow_signup: typing.Optional[builtins.bool] = None,
        identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
        user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
    ) -> None:
        '''Properties which configures the Identity Pool.

        :param allow_signup: Allow self sign up. Default: - false
        :param identity_pool_options: Configuration for the Identity Pool.
        :param user_pool: User provided Cognito UserPool. Default: - a userpool with mfa will be created.
        '''
        if isinstance(identity_pool_options, dict):
            identity_pool_options = _aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps(**identity_pool_options)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__222a3b2caa10c1bfa3835077067d8216decf681bd0f8bec700ca69ceace9e3e8)
            check_type(argname="argument allow_signup", value=allow_signup, expected_type=type_hints["allow_signup"])
            check_type(argname="argument identity_pool_options", value=identity_pool_options, expected_type=type_hints["identity_pool_options"])
            check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if allow_signup is not None:
            self._values["allow_signup"] = allow_signup
        if identity_pool_options is not None:
            self._values["identity_pool_options"] = identity_pool_options
        if user_pool is not None:
            self._values["user_pool"] = user_pool

    @builtins.property
    def allow_signup(self) -> typing.Optional[builtins.bool]:
        '''Allow self sign up.

        :default: - false
        '''
        result = self._values.get("allow_signup")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def identity_pool_options(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps]:
        '''Configuration for the Identity Pool.'''
        result = self._values.get("identity_pool_options")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps], result)

    @builtins.property
    def user_pool(self) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool]:
        '''User provided Cognito UserPool.

        :default: - a userpool with mfa will be created.
        '''
        result = self._values.get("user_pool")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UserIdentityProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class UserPoolWithMfa(
    _aws_cdk_aws_cognito_ceddda9d.UserPool,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws/pdk.identity.UserPoolWithMfa",
):
    '''Configures a UserPool with MFA across SMS/TOTP using sane defaults.'''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        account_recovery: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AccountRecovery] = None,
        advanced_security_mode: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AdvancedSecurityMode] = None,
        auto_verify: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
        custom_attributes: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_cognito_ceddda9d.ICustomAttribute]] = None,
        custom_sender_kms_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
        deletion_protection: typing.Optional[builtins.bool] = None,
        device_tracking: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.DeviceTracking, typing.Dict[builtins.str, typing.Any]]] = None,
        email: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolEmail] = None,
        enable_sms_role: typing.Optional[builtins.bool] = None,
        keep_original: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
        lambda_triggers: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
        mfa: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.Mfa] = None,
        mfa_message: typing.Optional[builtins.str] = None,
        mfa_second_factor: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor, typing.Dict[builtins.str, typing.Any]]] = None,
        password_policy: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.PasswordPolicy, typing.Dict[builtins.str, typing.Any]]] = None,
        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
        self_sign_up_enabled: typing.Optional[builtins.bool] = None,
        sign_in_aliases: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.SignInAliases, typing.Dict[builtins.str, typing.Any]]] = None,
        sign_in_case_sensitive: typing.Optional[builtins.bool] = None,
        sms_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
        sms_role_external_id: typing.Optional[builtins.str] = None,
        sns_region: typing.Optional[builtins.str] = None,
        standard_attributes: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.StandardAttributes, typing.Dict[builtins.str, typing.Any]]] = None,
        user_invitation: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
        user_pool_name: typing.Optional[builtins.str] = None,
        user_verification: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param account_recovery: How will a user be able to recover their account? Default: AccountRecovery.PHONE_WITHOUT_MFA_AND_EMAIL
        :param advanced_security_mode: The user pool's Advanced Security Mode. Default: - no value
        :param auto_verify: Attributes which Cognito will look to verify automatically upon user sign up. EMAIL and PHONE are the only available options. Default: - If ``signInAlias`` includes email and/or phone, they will be included in ``autoVerifiedAttributes`` by default. If absent, no attributes will be auto-verified.
        :param custom_attributes: Define a set of custom attributes that can be configured for each user in the user pool. Default: - No custom attributes.
        :param custom_sender_kms_key: This key will be used to encrypt temporary passwords and authorization codes that Amazon Cognito generates. Default: - no key ID configured
        :param deletion_protection: Indicates whether the user pool should have deletion protection enabled. Default: false
        :param device_tracking: Device tracking settings. Default: - see defaults on each property of DeviceTracking.
        :param email: Email settings for a user pool. Default: - cognito will use the default email configuration
        :param enable_sms_role: Setting this would explicitly enable or disable SMS role creation. When left unspecified, CDK will determine based on other properties if a role is needed or not. Default: - CDK will determine based on other properties of the user pool if an SMS role should be created or not.
        :param keep_original: Attributes which Cognito will look to handle changes to the value of your users' email address and phone number attributes. EMAIL and PHONE are the only available options. Default: - Nothing is kept.
        :param lambda_triggers: Lambda functions to use for supported Cognito triggers. Default: - No Lambda triggers.
        :param mfa: Configure whether users of this user pool can or are required use MFA to sign in. Default: Mfa.OFF
        :param mfa_message: The SMS message template sent during MFA verification. Use '{####}' in the template where Cognito should insert the verification code. Default: 'Your authentication code is {####}.'
        :param mfa_second_factor: Configure the MFA types that users can use in this user pool. Ignored if ``mfa`` is set to ``OFF``. Default: - { sms: true, otp: false }, if ``mfa`` is set to ``OPTIONAL`` or ``REQUIRED``. { sms: false, otp: false }, otherwise
        :param password_policy: Password policy for this user pool. Default: - see defaults on each property of PasswordPolicy.
        :param removal_policy: Policy to apply when the user pool is removed from the stack. Default: RemovalPolicy.RETAIN
        :param self_sign_up_enabled: Whether self sign-up should be enabled. To configure self sign-up configuration use the ``userVerification`` property. Default: - false
        :param sign_in_aliases: Methods in which a user registers or signs in to a user pool. Allows either username with aliases OR sign in with email, phone, or both. Read the sections on usernames and aliases to learn more - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html To match with 'Option 1' in the above link, with a verified email, this property should be set to ``{ username: true, email: true }``. To match with 'Option 2' in the above link with both a verified email and phone number, this property should be set to ``{ email: true, phone: true }``. Default: { username: true }
        :param sign_in_case_sensitive: Whether sign-in aliases should be evaluated with case sensitivity. For example, when this option is set to false, users will be able to sign in using either ``MyUsername`` or ``myusername``. Default: true
        :param sms_role: The IAM role that Cognito will assume while sending SMS messages. Default: - a new IAM role is created.
        :param sms_role_external_id: The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional. Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html This property will be ignored if ``smsRole`` is not specified. Default: - No external id will be configured.
        :param sns_region: The region to integrate with SNS to send SMS messages. This property will do nothing if SMS configuration is not configured. Default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
        :param standard_attributes: The set of attributes that are required for every user in the user pool. Read more on attributes here - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html Default: - All standard attributes are optional and mutable.
        :param user_invitation: Configuration around admins signing up users into a user pool. Default: - see defaults in UserInvitationConfig.
        :param user_pool_name: Name of the user pool. Default: - automatically generated name by CloudFormation at deploy time.
        :param user_verification: Configuration around users signing themselves up to the user pool. Enable or disable self sign-up via the ``selfSignUpEnabled`` property. Default: - see defaults in UserVerificationConfig.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa66be073edba83d19edc44f0da937d528deb57625d13c7719a5f653bf5482b8)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = UserPoolWithMfaProps(
            account_recovery=account_recovery,
            advanced_security_mode=advanced_security_mode,
            auto_verify=auto_verify,
            custom_attributes=custom_attributes,
            custom_sender_kms_key=custom_sender_kms_key,
            deletion_protection=deletion_protection,
            device_tracking=device_tracking,
            email=email,
            enable_sms_role=enable_sms_role,
            keep_original=keep_original,
            lambda_triggers=lambda_triggers,
            mfa=mfa,
            mfa_message=mfa_message,
            mfa_second_factor=mfa_second_factor,
            password_policy=password_policy,
            removal_policy=removal_policy,
            self_sign_up_enabled=self_sign_up_enabled,
            sign_in_aliases=sign_in_aliases,
            sign_in_case_sensitive=sign_in_case_sensitive,
            sms_role=sms_role,
            sms_role_external_id=sms_role_external_id,
            sns_region=sns_region,
            standard_attributes=standard_attributes,
            user_invitation=user_invitation,
            user_pool_name=user_pool_name,
            user_verification=user_verification,
        )

        jsii.create(self.__class__, self, [scope, id, props])


@jsii.data_type(
    jsii_type="@aws/pdk.identity.UserPoolWithMfaProps",
    jsii_struct_bases=[_aws_cdk_aws_cognito_ceddda9d.UserPoolProps],
    name_mapping={
        "account_recovery": "accountRecovery",
        "advanced_security_mode": "advancedSecurityMode",
        "auto_verify": "autoVerify",
        "custom_attributes": "customAttributes",
        "custom_sender_kms_key": "customSenderKmsKey",
        "deletion_protection": "deletionProtection",
        "device_tracking": "deviceTracking",
        "email": "email",
        "enable_sms_role": "enableSmsRole",
        "keep_original": "keepOriginal",
        "lambda_triggers": "lambdaTriggers",
        "mfa": "mfa",
        "mfa_message": "mfaMessage",
        "mfa_second_factor": "mfaSecondFactor",
        "password_policy": "passwordPolicy",
        "removal_policy": "removalPolicy",
        "self_sign_up_enabled": "selfSignUpEnabled",
        "sign_in_aliases": "signInAliases",
        "sign_in_case_sensitive": "signInCaseSensitive",
        "sms_role": "smsRole",
        "sms_role_external_id": "smsRoleExternalId",
        "sns_region": "snsRegion",
        "standard_attributes": "standardAttributes",
        "user_invitation": "userInvitation",
        "user_pool_name": "userPoolName",
        "user_verification": "userVerification",
    },
)
class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
    def __init__(
        self,
        *,
        account_recovery: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AccountRecovery] = None,
        advanced_security_mode: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AdvancedSecurityMode] = None,
        auto_verify: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
        custom_attributes: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_cognito_ceddda9d.ICustomAttribute]] = None,
        custom_sender_kms_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
        deletion_protection: typing.Optional[builtins.bool] = None,
        device_tracking: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.DeviceTracking, typing.Dict[builtins.str, typing.Any]]] = None,
        email: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolEmail] = None,
        enable_sms_role: typing.Optional[builtins.bool] = None,
        keep_original: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
        lambda_triggers: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
        mfa: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.Mfa] = None,
        mfa_message: typing.Optional[builtins.str] = None,
        mfa_second_factor: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor, typing.Dict[builtins.str, typing.Any]]] = None,
        password_policy: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.PasswordPolicy, typing.Dict[builtins.str, typing.Any]]] = None,
        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
        self_sign_up_enabled: typing.Optional[builtins.bool] = None,
        sign_in_aliases: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.SignInAliases, typing.Dict[builtins.str, typing.Any]]] = None,
        sign_in_case_sensitive: typing.Optional[builtins.bool] = None,
        sms_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
        sms_role_external_id: typing.Optional[builtins.str] = None,
        sns_region: typing.Optional[builtins.str] = None,
        standard_attributes: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.StandardAttributes, typing.Dict[builtins.str, typing.Any]]] = None,
        user_invitation: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
        user_pool_name: typing.Optional[builtins.str] = None,
        user_verification: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''UserPoolWithMfa props.

        :param account_recovery: How will a user be able to recover their account? Default: AccountRecovery.PHONE_WITHOUT_MFA_AND_EMAIL
        :param advanced_security_mode: The user pool's Advanced Security Mode. Default: - no value
        :param auto_verify: Attributes which Cognito will look to verify automatically upon user sign up. EMAIL and PHONE are the only available options. Default: - If ``signInAlias`` includes email and/or phone, they will be included in ``autoVerifiedAttributes`` by default. If absent, no attributes will be auto-verified.
        :param custom_attributes: Define a set of custom attributes that can be configured for each user in the user pool. Default: - No custom attributes.
        :param custom_sender_kms_key: This key will be used to encrypt temporary passwords and authorization codes that Amazon Cognito generates. Default: - no key ID configured
        :param deletion_protection: Indicates whether the user pool should have deletion protection enabled. Default: false
        :param device_tracking: Device tracking settings. Default: - see defaults on each property of DeviceTracking.
        :param email: Email settings for a user pool. Default: - cognito will use the default email configuration
        :param enable_sms_role: Setting this would explicitly enable or disable SMS role creation. When left unspecified, CDK will determine based on other properties if a role is needed or not. Default: - CDK will determine based on other properties of the user pool if an SMS role should be created or not.
        :param keep_original: Attributes which Cognito will look to handle changes to the value of your users' email address and phone number attributes. EMAIL and PHONE are the only available options. Default: - Nothing is kept.
        :param lambda_triggers: Lambda functions to use for supported Cognito triggers. Default: - No Lambda triggers.
        :param mfa: Configure whether users of this user pool can or are required use MFA to sign in. Default: Mfa.OFF
        :param mfa_message: The SMS message template sent during MFA verification. Use '{####}' in the template where Cognito should insert the verification code. Default: 'Your authentication code is {####}.'
        :param mfa_second_factor: Configure the MFA types that users can use in this user pool. Ignored if ``mfa`` is set to ``OFF``. Default: - { sms: true, otp: false }, if ``mfa`` is set to ``OPTIONAL`` or ``REQUIRED``. { sms: false, otp: false }, otherwise
        :param password_policy: Password policy for this user pool. Default: - see defaults on each property of PasswordPolicy.
        :param removal_policy: Policy to apply when the user pool is removed from the stack. Default: RemovalPolicy.RETAIN
        :param self_sign_up_enabled: Whether self sign-up should be enabled. To configure self sign-up configuration use the ``userVerification`` property. Default: - false
        :param sign_in_aliases: Methods in which a user registers or signs in to a user pool. Allows either username with aliases OR sign in with email, phone, or both. Read the sections on usernames and aliases to learn more - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html To match with 'Option 1' in the above link, with a verified email, this property should be set to ``{ username: true, email: true }``. To match with 'Option 2' in the above link with both a verified email and phone number, this property should be set to ``{ email: true, phone: true }``. Default: { username: true }
        :param sign_in_case_sensitive: Whether sign-in aliases should be evaluated with case sensitivity. For example, when this option is set to false, users will be able to sign in using either ``MyUsername`` or ``myusername``. Default: true
        :param sms_role: The IAM role that Cognito will assume while sending SMS messages. Default: - a new IAM role is created.
        :param sms_role_external_id: The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional. Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html This property will be ignored if ``smsRole`` is not specified. Default: - No external id will be configured.
        :param sns_region: The region to integrate with SNS to send SMS messages. This property will do nothing if SMS configuration is not configured. Default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
        :param standard_attributes: The set of attributes that are required for every user in the user pool. Read more on attributes here - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html Default: - All standard attributes are optional and mutable.
        :param user_invitation: Configuration around admins signing up users into a user pool. Default: - see defaults in UserInvitationConfig.
        :param user_pool_name: Name of the user pool. Default: - automatically generated name by CloudFormation at deploy time.
        :param user_verification: Configuration around users signing themselves up to the user pool. Enable or disable self sign-up via the ``selfSignUpEnabled`` property. Default: - see defaults in UserVerificationConfig.
        '''
        if isinstance(auto_verify, dict):
            auto_verify = _aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs(**auto_verify)
        if isinstance(device_tracking, dict):
            device_tracking = _aws_cdk_aws_cognito_ceddda9d.DeviceTracking(**device_tracking)
        if isinstance(keep_original, dict):
            keep_original = _aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs(**keep_original)
        if isinstance(lambda_triggers, dict):
            lambda_triggers = _aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers(**lambda_triggers)
        if isinstance(mfa_second_factor, dict):
            mfa_second_factor = _aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor(**mfa_second_factor)
        if isinstance(password_policy, dict):
            password_policy = _aws_cdk_aws_cognito_ceddda9d.PasswordPolicy(**password_policy)
        if isinstance(sign_in_aliases, dict):
            sign_in_aliases = _aws_cdk_aws_cognito_ceddda9d.SignInAliases(**sign_in_aliases)
        if isinstance(standard_attributes, dict):
            standard_attributes = _aws_cdk_aws_cognito_ceddda9d.StandardAttributes(**standard_attributes)
        if isinstance(user_invitation, dict):
            user_invitation = _aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig(**user_invitation)
        if isinstance(user_verification, dict):
            user_verification = _aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig(**user_verification)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4e225bd23db65e1b9bdf7a2e58c785a8fc5274a7f7eefd8ff5e9901dab81ff5)
            check_type(argname="argument account_recovery", value=account_recovery, expected_type=type_hints["account_recovery"])
            check_type(argname="argument advanced_security_mode", value=advanced_security_mode, expected_type=type_hints["advanced_security_mode"])
            check_type(argname="argument auto_verify", value=auto_verify, expected_type=type_hints["auto_verify"])
            check_type(argname="argument custom_attributes", value=custom_attributes, expected_type=type_hints["custom_attributes"])
            check_type(argname="argument custom_sender_kms_key", value=custom_sender_kms_key, expected_type=type_hints["custom_sender_kms_key"])
            check_type(argname="argument deletion_protection", value=deletion_protection, expected_type=type_hints["deletion_protection"])
            check_type(argname="argument device_tracking", value=device_tracking, expected_type=type_hints["device_tracking"])
            check_type(argname="argument email", value=email, expected_type=type_hints["email"])
            check_type(argname="argument enable_sms_role", value=enable_sms_role, expected_type=type_hints["enable_sms_role"])
            check_type(argname="argument keep_original", value=keep_original, expected_type=type_hints["keep_original"])
            check_type(argname="argument lambda_triggers", value=lambda_triggers, expected_type=type_hints["lambda_triggers"])
            check_type(argname="argument mfa", value=mfa, expected_type=type_hints["mfa"])
            check_type(argname="argument mfa_message", value=mfa_message, expected_type=type_hints["mfa_message"])
            check_type(argname="argument mfa_second_factor", value=mfa_second_factor, expected_type=type_hints["mfa_second_factor"])
            check_type(argname="argument password_policy", value=password_policy, expected_type=type_hints["password_policy"])
            check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
            check_type(argname="argument self_sign_up_enabled", value=self_sign_up_enabled, expected_type=type_hints["self_sign_up_enabled"])
            check_type(argname="argument sign_in_aliases", value=sign_in_aliases, expected_type=type_hints["sign_in_aliases"])
            check_type(argname="argument sign_in_case_sensitive", value=sign_in_case_sensitive, expected_type=type_hints["sign_in_case_sensitive"])
            check_type(argname="argument sms_role", value=sms_role, expected_type=type_hints["sms_role"])
            check_type(argname="argument sms_role_external_id", value=sms_role_external_id, expected_type=type_hints["sms_role_external_id"])
            check_type(argname="argument sns_region", value=sns_region, expected_type=type_hints["sns_region"])
            check_type(argname="argument standard_attributes", value=standard_attributes, expected_type=type_hints["standard_attributes"])
            check_type(argname="argument user_invitation", value=user_invitation, expected_type=type_hints["user_invitation"])
            check_type(argname="argument user_pool_name", value=user_pool_name, expected_type=type_hints["user_pool_name"])
            check_type(argname="argument user_verification", value=user_verification, expected_type=type_hints["user_verification"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if account_recovery is not None:
            self._values["account_recovery"] = account_recovery
        if advanced_security_mode is not None:
            self._values["advanced_security_mode"] = advanced_security_mode
        if auto_verify is not None:
            self._values["auto_verify"] = auto_verify
        if custom_attributes is not None:
            self._values["custom_attributes"] = custom_attributes
        if custom_sender_kms_key is not None:
            self._values["custom_sender_kms_key"] = custom_sender_kms_key
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if device_tracking is not None:
            self._values["device_tracking"] = device_tracking
        if email is not None:
            self._values["email"] = email
        if enable_sms_role is not None:
            self._values["enable_sms_role"] = enable_sms_role
        if keep_original is not None:
            self._values["keep_original"] = keep_original
        if lambda_triggers is not None:
            self._values["lambda_triggers"] = lambda_triggers
        if mfa is not None:
            self._values["mfa"] = mfa
        if mfa_message is not None:
            self._values["mfa_message"] = mfa_message
        if mfa_second_factor is not None:
            self._values["mfa_second_factor"] = mfa_second_factor
        if password_policy is not None:
            self._values["password_policy"] = password_policy
        if removal_policy is not None:
            self._values["removal_policy"] = removal_policy
        if self_sign_up_enabled is not None:
            self._values["self_sign_up_enabled"] = self_sign_up_enabled
        if sign_in_aliases is not None:
            self._values["sign_in_aliases"] = sign_in_aliases
        if sign_in_case_sensitive is not None:
            self._values["sign_in_case_sensitive"] = sign_in_case_sensitive
        if sms_role is not None:
            self._values["sms_role"] = sms_role
        if sms_role_external_id is not None:
            self._values["sms_role_external_id"] = sms_role_external_id
        if sns_region is not None:
            self._values["sns_region"] = sns_region
        if standard_attributes is not None:
            self._values["standard_attributes"] = standard_attributes
        if user_invitation is not None:
            self._values["user_invitation"] = user_invitation
        if user_pool_name is not None:
            self._values["user_pool_name"] = user_pool_name
        if user_verification is not None:
            self._values["user_verification"] = user_verification

    @builtins.property
    def account_recovery(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AccountRecovery]:
        '''How will a user be able to recover their account?

        :default: AccountRecovery.PHONE_WITHOUT_MFA_AND_EMAIL
        '''
        result = self._values.get("account_recovery")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AccountRecovery], result)

    @builtins.property
    def advanced_security_mode(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AdvancedSecurityMode]:
        '''The user pool's Advanced Security Mode.

        :default: - no value
        '''
        result = self._values.get("advanced_security_mode")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AdvancedSecurityMode], result)

    @builtins.property
    def auto_verify(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs]:
        '''Attributes which Cognito will look to verify automatically upon user sign up.

        EMAIL and PHONE are the only available options.

        :default:

        - If ``signInAlias`` includes email and/or phone, they will be included in ``autoVerifiedAttributes`` by default.
        If absent, no attributes will be auto-verified.
        '''
        result = self._values.get("auto_verify")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs], result)

    @builtins.property
    def custom_attributes(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_cognito_ceddda9d.ICustomAttribute]]:
        '''Define a set of custom attributes that can be configured for each user in the user pool.

        :default: - No custom attributes.
        '''
        result = self._values.get("custom_attributes")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_cognito_ceddda9d.ICustomAttribute]], result)

    @builtins.property
    def custom_sender_kms_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey]:
        '''This key will be used to encrypt temporary passwords and authorization codes that Amazon Cognito generates.

        :default: - no key ID configured

        :see: https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-custom-sender-triggers.html
        '''
        result = self._values.get("custom_sender_kms_key")
        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey], result)

    @builtins.property
    def deletion_protection(self) -> typing.Optional[builtins.bool]:
        '''Indicates whether the user pool should have deletion protection enabled.

        :default: false
        '''
        result = self._values.get("deletion_protection")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def device_tracking(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.DeviceTracking]:
        '''Device tracking settings.

        :default: - see defaults on each property of DeviceTracking.
        '''
        result = self._values.get("device_tracking")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.DeviceTracking], result)

    @builtins.property
    def email(self) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolEmail]:
        '''Email settings for a user pool.

        :default: - cognito will use the default email configuration
        '''
        result = self._values.get("email")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolEmail], result)

    @builtins.property
    def enable_sms_role(self) -> typing.Optional[builtins.bool]:
        '''Setting this would explicitly enable or disable SMS role creation.

        When left unspecified, CDK will determine based on other properties if a role is needed or not.

        :default: - CDK will determine based on other properties of the user pool if an SMS role should be created or not.
        '''
        result = self._values.get("enable_sms_role")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def keep_original(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs]:
        '''Attributes which Cognito will look to handle changes to the value of your users' email address and phone number attributes.

        EMAIL and PHONE are the only available options.

        :default: - Nothing is kept.
        '''
        result = self._values.get("keep_original")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs], result)

    @builtins.property
    def lambda_triggers(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers]:
        '''Lambda functions to use for supported Cognito triggers.

        :default: - No Lambda triggers.

        :see: https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html
        '''
        result = self._values.get("lambda_triggers")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers], result)

    @builtins.property
    def mfa(self) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.Mfa]:
        '''Configure whether users of this user pool can or are required use MFA to sign in.

        :default: Mfa.OFF
        '''
        result = self._values.get("mfa")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.Mfa], result)

    @builtins.property
    def mfa_message(self) -> typing.Optional[builtins.str]:
        '''The SMS message template sent during MFA verification.

        Use '{####}' in the template where Cognito should insert the verification code.

        :default: 'Your authentication code is {####}.'
        '''
        result = self._values.get("mfa_message")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def mfa_second_factor(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor]:
        '''Configure the MFA types that users can use in this user pool.

        Ignored if ``mfa`` is set to ``OFF``.

        :default:

        - { sms: true, otp: false }, if ``mfa`` is set to ``OPTIONAL`` or ``REQUIRED``.
        { sms: false, otp: false }, otherwise
        '''
        result = self._values.get("mfa_second_factor")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor], result)

    @builtins.property
    def password_policy(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.PasswordPolicy]:
        '''Password policy for this user pool.

        :default: - see defaults on each property of PasswordPolicy.
        '''
        result = self._values.get("password_policy")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.PasswordPolicy], result)

    @builtins.property
    def removal_policy(self) -> typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy]:
        '''Policy to apply when the user pool is removed from the stack.

        :default: RemovalPolicy.RETAIN
        '''
        result = self._values.get("removal_policy")
        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy], result)

    @builtins.property
    def self_sign_up_enabled(self) -> typing.Optional[builtins.bool]:
        '''Whether self sign-up should be enabled.

        To configure self sign-up configuration use the ``userVerification`` property.

        :default: - false
        '''
        result = self._values.get("self_sign_up_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def sign_in_aliases(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.SignInAliases]:
        '''Methods in which a user registers or signs in to a user pool.

        Allows either username with aliases OR sign in with email, phone, or both.

        Read the sections on usernames and aliases to learn more -
        https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html

        To match with 'Option 1' in the above link, with a verified email, this property should be set to
        ``{ username: true, email: true }``. To match with 'Option 2' in the above link with both a verified email and phone
        number, this property should be set to ``{ email: true, phone: true }``.

        :default: { username: true }
        '''
        result = self._values.get("sign_in_aliases")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.SignInAliases], result)

    @builtins.property
    def sign_in_case_sensitive(self) -> typing.Optional[builtins.bool]:
        '''Whether sign-in aliases should be evaluated with case sensitivity.

        For example, when this option is set to false, users will be able to sign in using either ``MyUsername`` or ``myusername``.

        :default: true
        '''
        result = self._values.get("sign_in_case_sensitive")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def sms_role(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
        '''The IAM role that Cognito will assume while sending SMS messages.

        :default: - a new IAM role is created.
        '''
        result = self._values.get("sms_role")
        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)

    @builtins.property
    def sms_role_external_id(self) -> typing.Optional[builtins.str]:
        '''The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional.

        Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html

        This property will be ignored if ``smsRole`` is not specified.

        :default: - No external id will be configured.
        '''
        result = self._values.get("sms_role_external_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def sns_region(self) -> typing.Optional[builtins.str]:
        '''The region to integrate with SNS to send SMS messages.

        This property will do nothing if SMS configuration is not configured.

        :default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
        '''
        result = self._values.get("sns_region")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def standard_attributes(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.StandardAttributes]:
        '''The set of attributes that are required for every user in the user pool.

        Read more on attributes here - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html

        :default: - All standard attributes are optional and mutable.
        '''
        result = self._values.get("standard_attributes")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.StandardAttributes], result)

    @builtins.property
    def user_invitation(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig]:
        '''Configuration around admins signing up users into a user pool.

        :default: - see defaults in UserInvitationConfig.
        '''
        result = self._values.get("user_invitation")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig], result)

    @builtins.property
    def user_pool_name(self) -> typing.Optional[builtins.str]:
        '''Name of the user pool.

        :default: - automatically generated name by CloudFormation at deploy time.
        '''
        result = self._values.get("user_pool_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def user_verification(
        self,
    ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig]:
        '''Configuration around users signing themselves up to the user pool.

        Enable or disable self sign-up via the ``selfSignUpEnabled`` property.

        :default: - see defaults in UserVerificationConfig.
        '''
        result = self._values.get("user_verification")
        return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UserPoolWithMfaProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "UserIdentity",
    "UserIdentityProps",
    "UserPoolWithMfa",
    "UserPoolWithMfaProps",
]

publication.publish()

def _typecheckingstub__3dda65570bf25bbaff83417268c7c0a7e08163811a20c7a7401e4a59fb1b444b(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    allow_signup: typing.Optional[builtins.bool] = None,
    identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
    user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__222a3b2caa10c1bfa3835077067d8216decf681bd0f8bec700ca69ceace9e3e8(
    *,
    allow_signup: typing.Optional[builtins.bool] = None,
    identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
    user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa66be073edba83d19edc44f0da937d528deb57625d13c7719a5f653bf5482b8(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    account_recovery: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AccountRecovery] = None,
    advanced_security_mode: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AdvancedSecurityMode] = None,
    auto_verify: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
    custom_attributes: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_cognito_ceddda9d.ICustomAttribute]] = None,
    custom_sender_kms_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
    deletion_protection: typing.Optional[builtins.bool] = None,
    device_tracking: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.DeviceTracking, typing.Dict[builtins.str, typing.Any]]] = None,
    email: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolEmail] = None,
    enable_sms_role: typing.Optional[builtins.bool] = None,
    keep_original: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
    lambda_triggers: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
    mfa: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.Mfa] = None,
    mfa_message: typing.Optional[builtins.str] = None,
    mfa_second_factor: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor, typing.Dict[builtins.str, typing.Any]]] = None,
    password_policy: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.PasswordPolicy, typing.Dict[builtins.str, typing.Any]]] = None,
    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
    self_sign_up_enabled: typing.Optional[builtins.bool] = None,
    sign_in_aliases: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.SignInAliases, typing.Dict[builtins.str, typing.Any]]] = None,
    sign_in_case_sensitive: typing.Optional[builtins.bool] = None,
    sms_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
    sms_role_external_id: typing.Optional[builtins.str] = None,
    sns_region: typing.Optional[builtins.str] = None,
    standard_attributes: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.StandardAttributes, typing.Dict[builtins.str, typing.Any]]] = None,
    user_invitation: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
    user_pool_name: typing.Optional[builtins.str] = None,
    user_verification: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4e225bd23db65e1b9bdf7a2e58c785a8fc5274a7f7eefd8ff5e9901dab81ff5(
    *,
    account_recovery: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AccountRecovery] = None,
    advanced_security_mode: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.AdvancedSecurityMode] = None,
    auto_verify: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
    custom_attributes: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_cognito_ceddda9d.ICustomAttribute]] = None,
    custom_sender_kms_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
    deletion_protection: typing.Optional[builtins.bool] = None,
    device_tracking: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.DeviceTracking, typing.Dict[builtins.str, typing.Any]]] = None,
    email: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPoolEmail] = None,
    enable_sms_role: typing.Optional[builtins.bool] = None,
    keep_original: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.KeepOriginalAttrs, typing.Dict[builtins.str, typing.Any]]] = None,
    lambda_triggers: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserPoolTriggers, typing.Dict[builtins.str, typing.Any]]] = None,
    mfa: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.Mfa] = None,
    mfa_message: typing.Optional[builtins.str] = None,
    mfa_second_factor: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.MfaSecondFactor, typing.Dict[builtins.str, typing.Any]]] = None,
    password_policy: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.PasswordPolicy, typing.Dict[builtins.str, typing.Any]]] = None,
    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
    self_sign_up_enabled: typing.Optional[builtins.bool] = None,
    sign_in_aliases: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.SignInAliases, typing.Dict[builtins.str, typing.Any]]] = None,
    sign_in_case_sensitive: typing.Optional[builtins.bool] = None,
    sms_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
    sms_role_external_id: typing.Optional[builtins.str] = None,
    sns_region: typing.Optional[builtins.str] = None,
    standard_attributes: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.StandardAttributes, typing.Dict[builtins.str, typing.Any]]] = None,
    user_invitation: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
    user_pool_name: typing.Optional[builtins.str] = None,
    user_verification: typing.Optional[typing.Union[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass



from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ..._jsii import *


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.ArrowFormat",
    jsii_struct_bases=[],
    name_mapping={
        "color": "color",
        "head": "head",
        "style": "style",
        "tail": "tail",
        "width": "width",
    },
)
class ArrowFormat:
    def __init__(
        self,
        *,
        color: typing.Union[builtins.str, builtins.bool],
        head: builtins.str,
        style: builtins.str,
        tail: builtins.str,
        width: jsii.Number,
    ) -> None:
        '''Theme arrow format definition.

        :param color: 
        :param head: 
        :param style: 
        :param tail: 
        :param width: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba6fc52a89c10a02b85f7992fb88c6b17e389a208c91fc77a95b59582d33b259)
            check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            check_type(argname="argument head", value=head, expected_type=type_hints["head"])
            check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            check_type(argname="argument tail", value=tail, expected_type=type_hints["tail"])
            check_type(argname="argument width", value=width, expected_type=type_hints["width"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "color": color,
            "head": head,
            "style": style,
            "tail": tail,
            "width": width,
        }

    @builtins.property
    def color(self) -> typing.Union[builtins.str, builtins.bool]:
        result = self._values.get("color")
        assert result is not None, "Required property 'color' is missing"
        return typing.cast(typing.Union[builtins.str, builtins.bool], result)

    @builtins.property
    def head(self) -> builtins.str:
        result = self._values.get("head")
        assert result is not None, "Required property 'head' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def style(self) -> builtins.str:
        result = self._values.get("style")
        assert result is not None, "Required property 'style' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def tail(self) -> builtins.str:
        result = self._values.get("tail")
        assert result is not None, "Required property 'tail' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def width(self) -> jsii.Number:
        result = self._values.get("width")
        assert result is not None, "Required property 'width' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ArrowFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.AwsCategoryDefinition",
    jsii_struct_bases=[],
    name_mapping={
        "fill_color": "fillColor",
        "gradient_color": "gradientColor",
        "id": "id",
        "name": "name",
        "font_color": "fontColor",
        "variants": "variants",
    },
)
class AwsCategoryDefinition:
    def __init__(
        self,
        *,
        fill_color: builtins.str,
        gradient_color: builtins.str,
        id: builtins.str,
        name: builtins.str,
        font_color: typing.Optional[builtins.str] = None,
        variants: typing.Optional[typing.Sequence[builtins.str]] = None,
    ) -> None:
        '''Category definition.

        :param fill_color: 
        :param gradient_color: 
        :param id: 
        :param name: 
        :param font_color: 
        :param variants: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7438791c1f64cf62ffded674cbdad6c4dd7dab2e8e7537d2ed04b4434b265874)
            check_type(argname="argument fill_color", value=fill_color, expected_type=type_hints["fill_color"])
            check_type(argname="argument gradient_color", value=gradient_color, expected_type=type_hints["gradient_color"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
            check_type(argname="argument variants", value=variants, expected_type=type_hints["variants"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "fill_color": fill_color,
            "gradient_color": gradient_color,
            "id": id,
            "name": name,
        }
        if font_color is not None:
            self._values["font_color"] = font_color
        if variants is not None:
            self._values["variants"] = variants

    @builtins.property
    def fill_color(self) -> builtins.str:
        result = self._values.get("fill_color")
        assert result is not None, "Required property 'fill_color' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def gradient_color(self) -> builtins.str:
        result = self._values.get("gradient_color")
        assert result is not None, "Required property 'gradient_color' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def font_color(self) -> typing.Optional[builtins.str]:
        result = self._values.get("font_color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def variants(self) -> typing.Optional[typing.List[builtins.str]]:
        result = self._values.get("variants")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AwsCategoryDefinition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="@aws/pdk.aws_arch.aws_arch.DarkPalette")
class DarkPalette(enum.Enum):
    '''Dark theme color palette.'''

    PUBLIC = "PUBLIC"
    PRIVATE = "PRIVATE"
    GENERIC = "GENERIC"
    PRIMARY = "PRIMARY"
    SECONDARY = "SECONDARY"
    TERTIARY = "TERTIARY"


@jsii.enum(jsii_type="@aws/pdk.aws_arch.aws_arch.DrawioAws4ParentShapes")
class DrawioAws4ParentShapes(enum.Enum):
    '''Draiwio aws4 parent shapes enum.'''

    RESOURCE_ICON = "RESOURCE_ICON"


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.DrawioAwsShapeStyleBase",
    jsii_struct_bases=[],
    name_mapping={
        "align": "align",
        "aspect": "aspect",
        "dashed": "dashed",
        "font_size": "fontSize",
        "font_style": "fontStyle",
        "gradient_direction": "gradientDirection",
        "html": "html",
        "outline_connect": "outlineConnect",
        "stroke_color": "strokeColor",
        "vertical_align": "verticalAlign",
        "vertical_label_position": "verticalLabelPosition",
        "pointer_event": "pointerEvent",
    },
)
class DrawioAwsShapeStyleBase:
    def __init__(
        self,
        *,
        align: builtins.str,
        aspect: builtins.str,
        dashed: jsii.Number,
        font_size: jsii.Number,
        font_style: typing.Union[builtins.str, jsii.Number],
        gradient_direction: builtins.str,
        html: jsii.Number,
        outline_connect: jsii.Number,
        stroke_color: builtins.str,
        vertical_align: builtins.str,
        vertical_label_position: builtins.str,
        pointer_event: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''Base definition of drawio aws shape style.

        :param align: 
        :param aspect: 
        :param dashed: 
        :param font_size: 
        :param font_style: 
        :param gradient_direction: 
        :param html: 
        :param outline_connect: 
        :param stroke_color: 
        :param vertical_align: 
        :param vertical_label_position: 
        :param pointer_event: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ec21d5477c0fbc4fdcb188636bb4730d477d2e3350db2bbaf89e38def763972)
            check_type(argname="argument align", value=align, expected_type=type_hints["align"])
            check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
            check_type(argname="argument dashed", value=dashed, expected_type=type_hints["dashed"])
            check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
            check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
            check_type(argname="argument gradient_direction", value=gradient_direction, expected_type=type_hints["gradient_direction"])
            check_type(argname="argument html", value=html, expected_type=type_hints["html"])
            check_type(argname="argument outline_connect", value=outline_connect, expected_type=type_hints["outline_connect"])
            check_type(argname="argument stroke_color", value=stroke_color, expected_type=type_hints["stroke_color"])
            check_type(argname="argument vertical_align", value=vertical_align, expected_type=type_hints["vertical_align"])
            check_type(argname="argument vertical_label_position", value=vertical_label_position, expected_type=type_hints["vertical_label_position"])
            check_type(argname="argument pointer_event", value=pointer_event, expected_type=type_hints["pointer_event"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "align": align,
            "aspect": aspect,
            "dashed": dashed,
            "font_size": font_size,
            "font_style": font_style,
            "gradient_direction": gradient_direction,
            "html": html,
            "outline_connect": outline_connect,
            "stroke_color": stroke_color,
            "vertical_align": vertical_align,
            "vertical_label_position": vertical_label_position,
        }
        if pointer_event is not None:
            self._values["pointer_event"] = pointer_event

    @builtins.property
    def align(self) -> builtins.str:
        result = self._values.get("align")
        assert result is not None, "Required property 'align' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aspect(self) -> builtins.str:
        result = self._values.get("aspect")
        assert result is not None, "Required property 'aspect' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashed(self) -> jsii.Number:
        result = self._values.get("dashed")
        assert result is not None, "Required property 'dashed' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def font_size(self) -> jsii.Number:
        result = self._values.get("font_size")
        assert result is not None, "Required property 'font_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def font_style(self) -> typing.Union[builtins.str, jsii.Number]:
        result = self._values.get("font_style")
        assert result is not None, "Required property 'font_style' is missing"
        return typing.cast(typing.Union[builtins.str, jsii.Number], result)

    @builtins.property
    def gradient_direction(self) -> builtins.str:
        result = self._values.get("gradient_direction")
        assert result is not None, "Required property 'gradient_direction' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def html(self) -> jsii.Number:
        result = self._values.get("html")
        assert result is not None, "Required property 'html' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def outline_connect(self) -> jsii.Number:
        result = self._values.get("outline_connect")
        assert result is not None, "Required property 'outline_connect' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def stroke_color(self) -> builtins.str:
        result = self._values.get("stroke_color")
        assert result is not None, "Required property 'stroke_color' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def vertical_align(self) -> builtins.str:
        result = self._values.get("vertical_align")
        assert result is not None, "Required property 'vertical_align' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def vertical_label_position(self) -> builtins.str:
        result = self._values.get("vertical_label_position")
        assert result is not None, "Required property 'vertical_label_position' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def pointer_event(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("pointer_event")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DrawioAwsShapeStyleBase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.GroupFormat",
    jsii_struct_bases=[],
    name_mapping={
        "bgcolor": "bgcolor",
        "border_color": "borderColor",
        "border_style": "borderStyle",
        "color": "color",
        "icon_png": "iconPng",
        "label_location": "labelLocation",
    },
)
class GroupFormat:
    def __init__(
        self,
        *,
        bgcolor: typing.Union[builtins.str, builtins.bool],
        border_color: typing.Union[builtins.str, builtins.bool],
        border_style: builtins.str,
        color: typing.Union[builtins.str, builtins.bool],
        icon_png: typing.Optional[builtins.str] = None,
        label_location: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Theme group format definition.

        :param bgcolor: 
        :param border_color: 
        :param border_style: 
        :param color: 
        :param icon_png: 
        :param label_location: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f402ced03f6eb2912e9526ef781533e01395e2dd9f549ab8909d25a4e6a23749)
            check_type(argname="argument bgcolor", value=bgcolor, expected_type=type_hints["bgcolor"])
            check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
            check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
            check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            check_type(argname="argument icon_png", value=icon_png, expected_type=type_hints["icon_png"])
            check_type(argname="argument label_location", value=label_location, expected_type=type_hints["label_location"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "bgcolor": bgcolor,
            "border_color": border_color,
            "border_style": border_style,
            "color": color,
        }
        if icon_png is not None:
            self._values["icon_png"] = icon_png
        if label_location is not None:
            self._values["label_location"] = label_location

    @builtins.property
    def bgcolor(self) -> typing.Union[builtins.str, builtins.bool]:
        result = self._values.get("bgcolor")
        assert result is not None, "Required property 'bgcolor' is missing"
        return typing.cast(typing.Union[builtins.str, builtins.bool], result)

    @builtins.property
    def border_color(self) -> typing.Union[builtins.str, builtins.bool]:
        result = self._values.get("border_color")
        assert result is not None, "Required property 'border_color' is missing"
        return typing.cast(typing.Union[builtins.str, builtins.bool], result)

    @builtins.property
    def border_style(self) -> builtins.str:
        result = self._values.get("border_style")
        assert result is not None, "Required property 'border_style' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def color(self) -> typing.Union[builtins.str, builtins.bool]:
        result = self._values.get("color")
        assert result is not None, "Required property 'color' is missing"
        return typing.cast(typing.Union[builtins.str, builtins.bool], result)

    @builtins.property
    def icon_png(self) -> typing.Optional[builtins.str]:
        result = self._values.get("icon_png")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def label_location(self) -> typing.Optional[builtins.str]:
        result = self._values.get("label_location")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GroupFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="@aws/pdk.aws_arch.aws_arch.LightPalette")
class LightPalette(enum.Enum):
    '''Light theme color palette.'''

    PUBLIC = "PUBLIC"
    PRIVATE = "PRIVATE"
    GENERIC = "GENERIC"
    PRIMARY = "PRIMARY"
    SECONDARY = "SECONDARY"
    TERTIARY = "TERTIARY"


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.ParsedAssetKey",
    jsii_struct_bases=[],
    name_mapping={
        "asset_key": "assetKey",
        "basename": "basename",
        "category": "category",
        "instance_type": "instanceType",
        "iot_thing": "iotThing",
        "resource": "resource",
        "service": "service",
    },
)
class ParsedAssetKey:
    def __init__(
        self,
        *,
        asset_key: builtins.str,
        basename: builtins.str,
        category: builtins.str,
        instance_type: typing.Optional[builtins.str] = None,
        iot_thing: typing.Optional[builtins.str] = None,
        resource: typing.Optional[builtins.str] = None,
        service: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Parsed asset key.

        :param asset_key: Reference to the full key that was parsed.
        :param basename: The last segment of the key (which is the nested icon). For instances and things this includes the dir prefix.
        :param category: Category id.
        :param instance_type: The instance type if key is for an ec2 instance.
        :param iot_thing: The iot thing if key is for an iot thing.
        :param resource: Resource id if key is for a resource.
        :param service: Service id if key is partitioned by resource.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15909d4df3070e0677bbcfd120c5bbbe12f961d908645e589a9c4f6e0f9d5057)
            check_type(argname="argument asset_key", value=asset_key, expected_type=type_hints["asset_key"])
            check_type(argname="argument basename", value=basename, expected_type=type_hints["basename"])
            check_type(argname="argument category", value=category, expected_type=type_hints["category"])
            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
            check_type(argname="argument iot_thing", value=iot_thing, expected_type=type_hints["iot_thing"])
            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "asset_key": asset_key,
            "basename": basename,
            "category": category,
        }
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if iot_thing is not None:
            self._values["iot_thing"] = iot_thing
        if resource is not None:
            self._values["resource"] = resource
        if service is not None:
            self._values["service"] = service

    @builtins.property
    def asset_key(self) -> builtins.str:
        '''Reference to the full key that was parsed.'''
        result = self._values.get("asset_key")
        assert result is not None, "Required property 'asset_key' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def basename(self) -> builtins.str:
        '''The last segment of the key (which is the nested icon).

        For instances and things this includes the dir prefix.
        '''
        result = self._values.get("basename")
        assert result is not None, "Required property 'basename' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def category(self) -> builtins.str:
        '''Category id.'''
        result = self._values.get("category")
        assert result is not None, "Required property 'category' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def instance_type(self) -> typing.Optional[builtins.str]:
        '''The instance type if key is for an ec2 instance.'''
        result = self._values.get("instance_type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def iot_thing(self) -> typing.Optional[builtins.str]:
        '''The iot thing if key is for an iot thing.'''
        result = self._values.get("iot_thing")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def resource(self) -> typing.Optional[builtins.str]:
        '''Resource id if key is for a resource.'''
        result = self._values.get("resource")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def service(self) -> typing.Optional[builtins.str]:
        '''Service id if key is partitioned by resource.'''
        result = self._values.get("service")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ParsedAssetKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.Theme",
    jsii_struct_bases=[],
    name_mapping={
        "arrows": "arrows",
        "backgrounds": "backgrounds",
        "groups": "groups",
        "id": "id",
        "text": "text",
    },
)
class Theme:
    def __init__(
        self,
        *,
        arrows: typing.Union["ThemeArrows", typing.Dict[builtins.str, typing.Any]],
        backgrounds: typing.Union["ThemeBackgrounds", typing.Dict[builtins.str, typing.Any]],
        groups: typing.Union["ThemeGroups", typing.Dict[builtins.str, typing.Any]],
        id: builtins.str,
        text: typing.Union["ThemeText", typing.Dict[builtins.str, typing.Any]],
    ) -> None:
        '''Theme definition.

        :param arrows: 
        :param backgrounds: 
        :param groups: 
        :param id: 
        :param text: 
        '''
        if isinstance(arrows, dict):
            arrows = ThemeArrows(**arrows)
        if isinstance(backgrounds, dict):
            backgrounds = ThemeBackgrounds(**backgrounds)
        if isinstance(groups, dict):
            groups = ThemeGroups(**groups)
        if isinstance(text, dict):
            text = ThemeText(**text)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be36d4a839c0be0442efde87ee3ac45ce44ad5f55a636361a98000c6dafb9656)
            check_type(argname="argument arrows", value=arrows, expected_type=type_hints["arrows"])
            check_type(argname="argument backgrounds", value=backgrounds, expected_type=type_hints["backgrounds"])
            check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument text", value=text, expected_type=type_hints["text"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "arrows": arrows,
            "backgrounds": backgrounds,
            "groups": groups,
            "id": id,
            "text": text,
        }

    @builtins.property
    def arrows(self) -> "ThemeArrows":
        result = self._values.get("arrows")
        assert result is not None, "Required property 'arrows' is missing"
        return typing.cast("ThemeArrows", result)

    @builtins.property
    def backgrounds(self) -> "ThemeBackgrounds":
        result = self._values.get("backgrounds")
        assert result is not None, "Required property 'backgrounds' is missing"
        return typing.cast("ThemeBackgrounds", result)

    @builtins.property
    def groups(self) -> "ThemeGroups":
        result = self._values.get("groups")
        assert result is not None, "Required property 'groups' is missing"
        return typing.cast("ThemeGroups", result)

    @builtins.property
    def id(self) -> builtins.str:
        result = self._values.get("id")
        assert result is not None, "Required property 'id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def text(self) -> "ThemeText":
        result = self._values.get("text")
        assert result is not None, "Required property 'text' is missing"
        return typing.cast("ThemeText", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Theme(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.ThemeArrows",
    jsii_struct_bases=[],
    name_mapping={
        "child": "child",
        "default": "default",
        "dependency": "dependency",
        "reference": "reference",
    },
)
class ThemeArrows:
    def __init__(
        self,
        *,
        child: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
        default: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
        dependency: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
        reference: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
    ) -> None:
        '''Theme arrow dictionary.

        :param child: 
        :param default: 
        :param dependency: 
        :param reference: 
        '''
        if isinstance(child, dict):
            child = ArrowFormat(**child)
        if isinstance(default, dict):
            default = ArrowFormat(**default)
        if isinstance(dependency, dict):
            dependency = ArrowFormat(**dependency)
        if isinstance(reference, dict):
            reference = ArrowFormat(**reference)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e548f1055616c1308146f72935a11a8ecbab1c52f81a6ed09179f073f6cafb7)
            check_type(argname="argument child", value=child, expected_type=type_hints["child"])
            check_type(argname="argument default", value=default, expected_type=type_hints["default"])
            check_type(argname="argument dependency", value=dependency, expected_type=type_hints["dependency"])
            check_type(argname="argument reference", value=reference, expected_type=type_hints["reference"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "child": child,
            "default": default,
            "dependency": dependency,
            "reference": reference,
        }

    @builtins.property
    def child(self) -> ArrowFormat:
        result = self._values.get("child")
        assert result is not None, "Required property 'child' is missing"
        return typing.cast(ArrowFormat, result)

    @builtins.property
    def default(self) -> ArrowFormat:
        result = self._values.get("default")
        assert result is not None, "Required property 'default' is missing"
        return typing.cast(ArrowFormat, result)

    @builtins.property
    def dependency(self) -> ArrowFormat:
        result = self._values.get("dependency")
        assert result is not None, "Required property 'dependency' is missing"
        return typing.cast(ArrowFormat, result)

    @builtins.property
    def reference(self) -> ArrowFormat:
        result = self._values.get("reference")
        assert result is not None, "Required property 'reference' is missing"
        return typing.cast(ArrowFormat, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ThemeArrows(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.ThemeBackgrounds",
    jsii_struct_bases=[],
    name_mapping={
        "base": "base",
        "generic": "generic",
        "private": "private",
        "public": "public",
    },
)
class ThemeBackgrounds:
    def __init__(
        self,
        *,
        base: builtins.str,
        generic: builtins.str,
        private: builtins.str,
        public: builtins.str,
    ) -> None:
        '''Theme background dictionary.

        :param base: 
        :param generic: 
        :param private: 
        :param public: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f00084e1feb4a2dc2a077115428de767505aa51223134e4e74ca8b36c7bcd13f)
            check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            check_type(argname="argument generic", value=generic, expected_type=type_hints["generic"])
            check_type(argname="argument private", value=private, expected_type=type_hints["private"])
            check_type(argname="argument public", value=public, expected_type=type_hints["public"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "base": base,
            "generic": generic,
            "private": private,
            "public": public,
        }

    @builtins.property
    def base(self) -> builtins.str:
        result = self._values.get("base")
        assert result is not None, "Required property 'base' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def generic(self) -> builtins.str:
        result = self._values.get("generic")
        assert result is not None, "Required property 'generic' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def private(self) -> builtins.str:
        result = self._values.get("private")
        assert result is not None, "Required property 'private' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def public(self) -> builtins.str:
        result = self._values.get("public")
        assert result is not None, "Required property 'public' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ThemeBackgrounds(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.ThemeGroups",
    jsii_struct_bases=[],
    name_mapping={
        "auto_scaling_group": "autoScalingGroup",
        "availability_zone": "availabilityZone",
        "aws_account": "awsAccount",
        "aws_io_t_greengrass": "awsIoTGreengrass",
        "aws_io_t_greengrass_deployment": "awsIoTGreengrassDeployment",
        "aws_step_functions_workflow": "awsStepFunctionsWorkflow",
        "cloud": "cloud",
        "cloud_alt": "cloudAlt",
        "corporate_data_center": "corporateDataCenter",
        "ec2_instance_contents": "ec2InstanceContents",
        "elastic_beanstalk_container": "elasticBeanstalkContainer",
        "generic": "generic",
        "generic_alt": "genericAlt",
        "private_subnet": "privateSubnet",
        "public_subnet": "publicSubnet",
        "region": "region",
        "security_group": "securityGroup",
        "server_contents": "serverContents",
        "spot_fleet": "spotFleet",
        "vpc": "vpc",
    },
)
class ThemeGroups:
    def __init__(
        self,
        *,
        auto_scaling_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        availability_zone: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        aws_account: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        aws_io_t_greengrass: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        aws_io_t_greengrass_deployment: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        aws_step_functions_workflow: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        cloud: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        cloud_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        corporate_data_center: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        ec2_instance_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        elastic_beanstalk_container: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        generic: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        generic_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        private_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        public_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        region: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        security_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        server_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        spot_fleet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
        vpc: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    ) -> None:
        '''Theme group dicionary.

        :param auto_scaling_group: 
        :param availability_zone: 
        :param aws_account: 
        :param aws_io_t_greengrass: 
        :param aws_io_t_greengrass_deployment: 
        :param aws_step_functions_workflow: 
        :param cloud: 
        :param cloud_alt: 
        :param corporate_data_center: 
        :param ec2_instance_contents: 
        :param elastic_beanstalk_container: 
        :param generic: 
        :param generic_alt: 
        :param private_subnet: 
        :param public_subnet: 
        :param region: 
        :param security_group: 
        :param server_contents: 
        :param spot_fleet: 
        :param vpc: 
        '''
        if isinstance(auto_scaling_group, dict):
            auto_scaling_group = GroupFormat(**auto_scaling_group)
        if isinstance(availability_zone, dict):
            availability_zone = GroupFormat(**availability_zone)
        if isinstance(aws_account, dict):
            aws_account = GroupFormat(**aws_account)
        if isinstance(aws_io_t_greengrass, dict):
            aws_io_t_greengrass = GroupFormat(**aws_io_t_greengrass)
        if isinstance(aws_io_t_greengrass_deployment, dict):
            aws_io_t_greengrass_deployment = GroupFormat(**aws_io_t_greengrass_deployment)
        if isinstance(aws_step_functions_workflow, dict):
            aws_step_functions_workflow = GroupFormat(**aws_step_functions_workflow)
        if isinstance(cloud, dict):
            cloud = GroupFormat(**cloud)
        if isinstance(cloud_alt, dict):
            cloud_alt = GroupFormat(**cloud_alt)
        if isinstance(corporate_data_center, dict):
            corporate_data_center = GroupFormat(**corporate_data_center)
        if isinstance(ec2_instance_contents, dict):
            ec2_instance_contents = GroupFormat(**ec2_instance_contents)
        if isinstance(elastic_beanstalk_container, dict):
            elastic_beanstalk_container = GroupFormat(**elastic_beanstalk_container)
        if isinstance(generic, dict):
            generic = GroupFormat(**generic)
        if isinstance(generic_alt, dict):
            generic_alt = GroupFormat(**generic_alt)
        if isinstance(private_subnet, dict):
            private_subnet = GroupFormat(**private_subnet)
        if isinstance(public_subnet, dict):
            public_subnet = GroupFormat(**public_subnet)
        if isinstance(region, dict):
            region = GroupFormat(**region)
        if isinstance(security_group, dict):
            security_group = GroupFormat(**security_group)
        if isinstance(server_contents, dict):
            server_contents = GroupFormat(**server_contents)
        if isinstance(spot_fleet, dict):
            spot_fleet = GroupFormat(**spot_fleet)
        if isinstance(vpc, dict):
            vpc = GroupFormat(**vpc)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9439ab787a388af5579ff9fbe78dfa641ee9b13ae9eb36548944a05cfc61e9e0)
            check_type(argname="argument auto_scaling_group", value=auto_scaling_group, expected_type=type_hints["auto_scaling_group"])
            check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
            check_type(argname="argument aws_account", value=aws_account, expected_type=type_hints["aws_account"])
            check_type(argname="argument aws_io_t_greengrass", value=aws_io_t_greengrass, expected_type=type_hints["aws_io_t_greengrass"])
            check_type(argname="argument aws_io_t_greengrass_deployment", value=aws_io_t_greengrass_deployment, expected_type=type_hints["aws_io_t_greengrass_deployment"])
            check_type(argname="argument aws_step_functions_workflow", value=aws_step_functions_workflow, expected_type=type_hints["aws_step_functions_workflow"])
            check_type(argname="argument cloud", value=cloud, expected_type=type_hints["cloud"])
            check_type(argname="argument cloud_alt", value=cloud_alt, expected_type=type_hints["cloud_alt"])
            check_type(argname="argument corporate_data_center", value=corporate_data_center, expected_type=type_hints["corporate_data_center"])
            check_type(argname="argument ec2_instance_contents", value=ec2_instance_contents, expected_type=type_hints["ec2_instance_contents"])
            check_type(argname="argument elastic_beanstalk_container", value=elastic_beanstalk_container, expected_type=type_hints["elastic_beanstalk_container"])
            check_type(argname="argument generic", value=generic, expected_type=type_hints["generic"])
            check_type(argname="argument generic_alt", value=generic_alt, expected_type=type_hints["generic_alt"])
            check_type(argname="argument private_subnet", value=private_subnet, expected_type=type_hints["private_subnet"])
            check_type(argname="argument public_subnet", value=public_subnet, expected_type=type_hints["public_subnet"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
            check_type(argname="argument server_contents", value=server_contents, expected_type=type_hints["server_contents"])
            check_type(argname="argument spot_fleet", value=spot_fleet, expected_type=type_hints["spot_fleet"])
            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "auto_scaling_group": auto_scaling_group,
            "availability_zone": availability_zone,
            "aws_account": aws_account,
            "aws_io_t_greengrass": aws_io_t_greengrass,
            "aws_io_t_greengrass_deployment": aws_io_t_greengrass_deployment,
            "aws_step_functions_workflow": aws_step_functions_workflow,
            "cloud": cloud,
            "cloud_alt": cloud_alt,
            "corporate_data_center": corporate_data_center,
            "ec2_instance_contents": ec2_instance_contents,
            "elastic_beanstalk_container": elastic_beanstalk_container,
            "generic": generic,
            "generic_alt": generic_alt,
            "private_subnet": private_subnet,
            "public_subnet": public_subnet,
            "region": region,
            "security_group": security_group,
            "server_contents": server_contents,
            "spot_fleet": spot_fleet,
            "vpc": vpc,
        }

    @builtins.property
    def auto_scaling_group(self) -> GroupFormat:
        result = self._values.get("auto_scaling_group")
        assert result is not None, "Required property 'auto_scaling_group' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def availability_zone(self) -> GroupFormat:
        result = self._values.get("availability_zone")
        assert result is not None, "Required property 'availability_zone' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def aws_account(self) -> GroupFormat:
        result = self._values.get("aws_account")
        assert result is not None, "Required property 'aws_account' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def aws_io_t_greengrass(self) -> GroupFormat:
        result = self._values.get("aws_io_t_greengrass")
        assert result is not None, "Required property 'aws_io_t_greengrass' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def aws_io_t_greengrass_deployment(self) -> GroupFormat:
        result = self._values.get("aws_io_t_greengrass_deployment")
        assert result is not None, "Required property 'aws_io_t_greengrass_deployment' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def aws_step_functions_workflow(self) -> GroupFormat:
        result = self._values.get("aws_step_functions_workflow")
        assert result is not None, "Required property 'aws_step_functions_workflow' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def cloud(self) -> GroupFormat:
        result = self._values.get("cloud")
        assert result is not None, "Required property 'cloud' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def cloud_alt(self) -> GroupFormat:
        result = self._values.get("cloud_alt")
        assert result is not None, "Required property 'cloud_alt' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def corporate_data_center(self) -> GroupFormat:
        result = self._values.get("corporate_data_center")
        assert result is not None, "Required property 'corporate_data_center' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def ec2_instance_contents(self) -> GroupFormat:
        result = self._values.get("ec2_instance_contents")
        assert result is not None, "Required property 'ec2_instance_contents' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def elastic_beanstalk_container(self) -> GroupFormat:
        result = self._values.get("elastic_beanstalk_container")
        assert result is not None, "Required property 'elastic_beanstalk_container' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def generic(self) -> GroupFormat:
        result = self._values.get("generic")
        assert result is not None, "Required property 'generic' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def generic_alt(self) -> GroupFormat:
        result = self._values.get("generic_alt")
        assert result is not None, "Required property 'generic_alt' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def private_subnet(self) -> GroupFormat:
        result = self._values.get("private_subnet")
        assert result is not None, "Required property 'private_subnet' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def public_subnet(self) -> GroupFormat:
        result = self._values.get("public_subnet")
        assert result is not None, "Required property 'public_subnet' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def region(self) -> GroupFormat:
        result = self._values.get("region")
        assert result is not None, "Required property 'region' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def security_group(self) -> GroupFormat:
        result = self._values.get("security_group")
        assert result is not None, "Required property 'security_group' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def server_contents(self) -> GroupFormat:
        result = self._values.get("server_contents")
        assert result is not None, "Required property 'server_contents' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def spot_fleet(self) -> GroupFormat:
        result = self._values.get("spot_fleet")
        assert result is not None, "Required property 'spot_fleet' is missing"
        return typing.cast(GroupFormat, result)

    @builtins.property
    def vpc(self) -> GroupFormat:
        result = self._values.get("vpc")
        assert result is not None, "Required property 'vpc' is missing"
        return typing.cast(GroupFormat, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ThemeGroups(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.ThemeText",
    jsii_struct_bases=[],
    name_mapping={
        "default": "default",
        "primary": "primary",
        "secondary": "secondary",
        "tertiary": "tertiary",
    },
)
class ThemeText:
    def __init__(
        self,
        *,
        default: builtins.str,
        primary: builtins.str,
        secondary: builtins.str,
        tertiary: builtins.str,
    ) -> None:
        '''Theme text dictionary.

        :param default: 
        :param primary: 
        :param secondary: 
        :param tertiary: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd06fec4869d649effbfec4bbe05b184587228d353867050827c622692924d17)
            check_type(argname="argument default", value=default, expected_type=type_hints["default"])
            check_type(argname="argument primary", value=primary, expected_type=type_hints["primary"])
            check_type(argname="argument secondary", value=secondary, expected_type=type_hints["secondary"])
            check_type(argname="argument tertiary", value=tertiary, expected_type=type_hints["tertiary"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "default": default,
            "primary": primary,
            "secondary": secondary,
            "tertiary": tertiary,
        }

    @builtins.property
    def default(self) -> builtins.str:
        result = self._values.get("default")
        assert result is not None, "Required property 'default' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def primary(self) -> builtins.str:
        result = self._values.get("primary")
        assert result is not None, "Required property 'primary' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def secondary(self) -> builtins.str:
        result = self._values.get("secondary")
        assert result is not None, "Required property 'secondary' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def tertiary(self) -> builtins.str:
        result = self._values.get("tertiary")
        assert result is not None, "Required property 'tertiary' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ThemeText(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@aws/pdk.aws_arch.aws_arch.DrawioAwsResourceIconStyleBase",
    jsii_struct_bases=[DrawioAwsShapeStyleBase],
    name_mapping={
        "align": "align",
        "aspect": "aspect",
        "dashed": "dashed",
        "font_size": "fontSize",
        "font_style": "fontStyle",
        "gradient_direction": "gradientDirection",
        "html": "html",
        "outline_connect": "outlineConnect",
        "stroke_color": "strokeColor",
        "vertical_align": "verticalAlign",
        "vertical_label_position": "verticalLabelPosition",
        "pointer_event": "pointerEvent",
        "fill_color": "fillColor",
        "font_color": "fontColor",
        "gradient_color": "gradientColor",
    },
)
class DrawioAwsResourceIconStyleBase(DrawioAwsShapeStyleBase):
    def __init__(
        self,
        *,
        align: builtins.str,
        aspect: builtins.str,
        dashed: jsii.Number,
        font_size: jsii.Number,
        font_style: typing.Union[builtins.str, jsii.Number],
        gradient_direction: builtins.str,
        html: jsii.Number,
        outline_connect: jsii.Number,
        stroke_color: builtins.str,
        vertical_align: builtins.str,
        vertical_label_position: builtins.str,
        pointer_event: typing.Optional[jsii.Number] = None,
        fill_color: builtins.str,
        font_color: builtins.str,
        gradient_color: builtins.str,
    ) -> None:
        '''Based style definition for drawio aws resource icon.

        :param align: 
        :param aspect: 
        :param dashed: 
        :param font_size: 
        :param font_style: 
        :param gradient_direction: 
        :param html: 
        :param outline_connect: 
        :param stroke_color: 
        :param vertical_align: 
        :param vertical_label_position: 
        :param pointer_event: 
        :param fill_color: 
        :param font_color: 
        :param gradient_color: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3e1cfa84f48bc9cfcc95a682906aa4858e4058b20238010650fa8c599551dea)
            check_type(argname="argument align", value=align, expected_type=type_hints["align"])
            check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
            check_type(argname="argument dashed", value=dashed, expected_type=type_hints["dashed"])
            check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
            check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
            check_type(argname="argument gradient_direction", value=gradient_direction, expected_type=type_hints["gradient_direction"])
            check_type(argname="argument html", value=html, expected_type=type_hints["html"])
            check_type(argname="argument outline_connect", value=outline_connect, expected_type=type_hints["outline_connect"])
            check_type(argname="argument stroke_color", value=stroke_color, expected_type=type_hints["stroke_color"])
            check_type(argname="argument vertical_align", value=vertical_align, expected_type=type_hints["vertical_align"])
            check_type(argname="argument vertical_label_position", value=vertical_label_position, expected_type=type_hints["vertical_label_position"])
            check_type(argname="argument pointer_event", value=pointer_event, expected_type=type_hints["pointer_event"])
            check_type(argname="argument fill_color", value=fill_color, expected_type=type_hints["fill_color"])
            check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
            check_type(argname="argument gradient_color", value=gradient_color, expected_type=type_hints["gradient_color"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "align": align,
            "aspect": aspect,
            "dashed": dashed,
            "font_size": font_size,
            "font_style": font_style,
            "gradient_direction": gradient_direction,
            "html": html,
            "outline_connect": outline_connect,
            "stroke_color": stroke_color,
            "vertical_align": vertical_align,
            "vertical_label_position": vertical_label_position,
            "fill_color": fill_color,
            "font_color": font_color,
            "gradient_color": gradient_color,
        }
        if pointer_event is not None:
            self._values["pointer_event"] = pointer_event

    @builtins.property
    def align(self) -> builtins.str:
        result = self._values.get("align")
        assert result is not None, "Required property 'align' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aspect(self) -> builtins.str:
        result = self._values.get("aspect")
        assert result is not None, "Required property 'aspect' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashed(self) -> jsii.Number:
        result = self._values.get("dashed")
        assert result is not None, "Required property 'dashed' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def font_size(self) -> jsii.Number:
        result = self._values.get("font_size")
        assert result is not None, "Required property 'font_size' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def font_style(self) -> typing.Union[builtins.str, jsii.Number]:
        result = self._values.get("font_style")
        assert result is not None, "Required property 'font_style' is missing"
        return typing.cast(typing.Union[builtins.str, jsii.Number], result)

    @builtins.property
    def gradient_direction(self) -> builtins.str:
        result = self._values.get("gradient_direction")
        assert result is not None, "Required property 'gradient_direction' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def html(self) -> jsii.Number:
        result = self._values.get("html")
        assert result is not None, "Required property 'html' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def outline_connect(self) -> jsii.Number:
        result = self._values.get("outline_connect")
        assert result is not None, "Required property 'outline_connect' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def stroke_color(self) -> builtins.str:
        result = self._values.get("stroke_color")
        assert result is not None, "Required property 'stroke_color' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def vertical_align(self) -> builtins.str:
        result = self._values.get("vertical_align")
        assert result is not None, "Required property 'vertical_align' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def vertical_label_position(self) -> builtins.str:
        result = self._values.get("vertical_label_position")
        assert result is not None, "Required property 'vertical_label_position' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def pointer_event(self) -> typing.Optional[jsii.Number]:
        result = self._values.get("pointer_event")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_color(self) -> builtins.str:
        result = self._values.get("fill_color")
        assert result is not None, "Required property 'fill_color' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def font_color(self) -> builtins.str:
        result = self._values.get("font_color")
        assert result is not None, "Required property 'font_color' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def gradient_color(self) -> builtins.str:
        result = self._values.get("gradient_color")
        assert result is not None, "Required property 'gradient_color' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DrawioAwsResourceIconStyleBase(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "ArrowFormat",
    "AwsCategoryDefinition",
    "DarkPalette",
    "DrawioAws4ParentShapes",
    "DrawioAwsResourceIconStyleBase",
    "DrawioAwsShapeStyleBase",
    "GroupFormat",
    "LightPalette",
    "ParsedAssetKey",
    "Theme",
    "ThemeArrows",
    "ThemeBackgrounds",
    "ThemeGroups",
    "ThemeText",
    "drawio_spec",
    "pricing_manifest",
]

publication.publish()

# Loading modules to ensure their types are registered with the jsii runtime library
from . import drawio_spec
from . import pricing_manifest

def _typecheckingstub__ba6fc52a89c10a02b85f7992fb88c6b17e389a208c91fc77a95b59582d33b259(
    *,
    color: typing.Union[builtins.str, builtins.bool],
    head: builtins.str,
    style: builtins.str,
    tail: builtins.str,
    width: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7438791c1f64cf62ffded674cbdad6c4dd7dab2e8e7537d2ed04b4434b265874(
    *,
    fill_color: builtins.str,
    gradient_color: builtins.str,
    id: builtins.str,
    name: builtins.str,
    font_color: typing.Optional[builtins.str] = None,
    variants: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ec21d5477c0fbc4fdcb188636bb4730d477d2e3350db2bbaf89e38def763972(
    *,
    align: builtins.str,
    aspect: builtins.str,
    dashed: jsii.Number,
    font_size: jsii.Number,
    font_style: typing.Union[builtins.str, jsii.Number],
    gradient_direction: builtins.str,
    html: jsii.Number,
    outline_connect: jsii.Number,
    stroke_color: builtins.str,
    vertical_align: builtins.str,
    vertical_label_position: builtins.str,
    pointer_event: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f402ced03f6eb2912e9526ef781533e01395e2dd9f549ab8909d25a4e6a23749(
    *,
    bgcolor: typing.Union[builtins.str, builtins.bool],
    border_color: typing.Union[builtins.str, builtins.bool],
    border_style: builtins.str,
    color: typing.Union[builtins.str, builtins.bool],
    icon_png: typing.Optional[builtins.str] = None,
    label_location: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15909d4df3070e0677bbcfd120c5bbbe12f961d908645e589a9c4f6e0f9d5057(
    *,
    asset_key: builtins.str,
    basename: builtins.str,
    category: builtins.str,
    instance_type: typing.Optional[builtins.str] = None,
    iot_thing: typing.Optional[builtins.str] = None,
    resource: typing.Optional[builtins.str] = None,
    service: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be36d4a839c0be0442efde87ee3ac45ce44ad5f55a636361a98000c6dafb9656(
    *,
    arrows: typing.Union[ThemeArrows, typing.Dict[builtins.str, typing.Any]],
    backgrounds: typing.Union[ThemeBackgrounds, typing.Dict[builtins.str, typing.Any]],
    groups: typing.Union[ThemeGroups, typing.Dict[builtins.str, typing.Any]],
    id: builtins.str,
    text: typing.Union[ThemeText, typing.Dict[builtins.str, typing.Any]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e548f1055616c1308146f72935a11a8ecbab1c52f81a6ed09179f073f6cafb7(
    *,
    child: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
    default: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
    dependency: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
    reference: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f00084e1feb4a2dc2a077115428de767505aa51223134e4e74ca8b36c7bcd13f(
    *,
    base: builtins.str,
    generic: builtins.str,
    private: builtins.str,
    public: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9439ab787a388af5579ff9fbe78dfa641ee9b13ae9eb36548944a05cfc61e9e0(
    *,
    auto_scaling_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    availability_zone: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    aws_account: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    aws_io_t_greengrass: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    aws_io_t_greengrass_deployment: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    aws_step_functions_workflow: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    cloud: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    cloud_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    corporate_data_center: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    ec2_instance_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    elastic_beanstalk_container: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    generic: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    generic_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    private_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    public_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    region: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    security_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    server_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    spot_fleet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
    vpc: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd06fec4869d649effbfec4bbe05b184587228d353867050827c622692924d17(
    *,
    default: builtins.str,
    primary: builtins.str,
    secondary: builtins.str,
    tertiary: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3e1cfa84f48bc9cfcc95a682906aa4858e4058b20238010650fa8c599551dea(
    *,
    align: builtins.str,
    aspect: builtins.str,
    dashed: jsii.Number,
    font_size: jsii.Number,
    font_style: typing.Union[builtins.str, jsii.Number],
    gradient_direction: builtins.str,
    html: jsii.Number,
    outline_connect: jsii.Number,
    stroke_color: builtins.str,
    vertical_align: builtins.str,
    vertical_label_position: builtins.str,
    pointer_event: typing.Optional[jsii.Number] = None,
    fill_color: builtins.str,
    font_color: builtins.str,
    gradient_color: builtins.str,
) -> None:
    """Type checking stubs"""
    pass



r'''
# AWS PDK

All documentation is located at: https://aws.github.io/aws-pdk

# aws-arch

Please refer to [Developer Guide](./docs/developer_guides/aws-arch/index.md).

# cdk-graph

Please refer to [Developer Guide](./docs/developer_guides/cdk-graph/index.md).

# cdk-graph-plugin-diagram

Please refer to [Developer Guide](./docs/developer_guides/cdk-graph-plugin-diagram/index.md).

# cdk-graph-plugin-threat-composer

Please refer to [Developer Guide](./docs/developer_guides/cdk-graph-plugin-threat-composer/index.md).

# cloudscape-react-ts-website

Please refer to [Developer Guide](./docs/developer_guides/cloudscape-react-ts-website/index.md).

# identity

Please refer to [Developer Guide](./docs/developer_guides/identity/index.md).

# infrastructure

Please refer to [Developer Guide](./docs/developer_guides/infrastructure/index.md).

# monorepo

Please refer to [Developer Guide](./docs/developer_guides/monorepo/index.md).

# pdk-nag

Please refer to [Developer Guide](./docs/developer_guides/pdk-nag/index.md).

# pipeline

Please refer to [Developer Guide](./docs/developer_guides/pipeline/index.md).

# static-website

Please refer to [Developer Guide](./docs/developer_guides/static-website/index.md).

# type-safe-api

Please refer to [Developer Guide](./docs/developer_guides/type-safe-api/index.md).
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

__all__ = [
    "aws_arch",
    "cdk_graph",
    "cdk_graph_plugin_diagram",
    "cdk_graph_plugin_threat_composer",
    "cloudscape_react_ts_website",
    "identity",
    "infrastructure",
    "monorepo",
    "pdk_nag",
    "pipeline",
    "static_website",
    "type_safe_api",
]

publication.publish()

# Loading modules to ensure their types are registered with the jsii runtime library
from . import aws_arch
from . import cdk_graph
from . import cdk_graph_plugin_diagram
from . import cdk_graph_plugin_threat_composer
from . import cloudscape_react_ts_website
from . import identity
from . import infrastructure
from . import monorepo
from . import pdk_nag
from . import pipeline
from . import static_website
from . import type_safe_api



import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws_pdk",
    "version": "0.26.15",
    "description": "@aws/pdk",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-pdk",
    "long_description_content_type": "text/markdown",
    "author": "AWS APJ COPE<apj-cope@amazon.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-pdk"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_pdk",
        "aws_pdk._jsii",
        "aws_pdk.aws_arch",
        "aws_pdk.aws_arch.aws_arch",
        "aws_pdk.aws_arch.aws_arch.drawio_spec",
        "aws_pdk.aws_arch.aws_arch.drawio_spec.aws4",
        "aws_pdk.aws_arch.aws_arch.pricing_manifest",
        "aws_pdk.cdk_graph",
        "aws_pdk.cdk_graph_plugin_diagram",
        "aws_pdk.cdk_graph_plugin_threat_composer",
        "aws_pdk.cloudscape_react_ts_website",
        "aws_pdk.identity",
        "aws_pdk.infrastructure",
        "aws_pdk.monorepo",
        "aws_pdk.monorepo.nx",
        "aws_pdk.monorepo.syncpack",
        "aws_pdk.monorepo.syncpack.base_group_config",
        "aws_pdk.monorepo.syncpack.custom_type_config",
        "aws_pdk.monorepo.syncpack.semver_group_config",
        "aws_pdk.monorepo.syncpack.version_group_config",
        "aws_pdk.pdk_nag",
        "aws_pdk.pipeline",
        "aws_pdk.static_website",
        "aws_pdk.type_safe_api"
    ],
    "package_data": {
        "aws_pdk._jsii": [
            "pdk@0.26.15.jsii.tgz"
        ],
        "aws_pdk": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.163.1, <3.0.0",
        "aws-cdk.aws-cognito-identitypool-alpha>=2.163.1.a0, <3.0.0",
        "cdk-nag>=2.31.0, <3.0.0",
        "constructs>=10.4.2, <11.0.0",
        "jsii>=1.104.0, <2.0.0",
        "projen>=0.82.8, <0.83.0",
        "publication>=0.0.3",
        "typeguard>=2.13.3,<4.3.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": [
        "src/aws_pdk/_jsii/bin/monorepo.nx-dir-hasher",
        "src/aws_pdk/_jsii/bin/pdk",
        "src/aws_pdk/_jsii/bin/type-safe-api"
    ]
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
